@@ -130,7 +130,7 @@ class facile_trigger_helper:
         :project_id variable aims gitlab id found on project >> General:
         """
         runnable_list = []
-        facile_env = "https://dev.facile.it"
+        facile_env = "dev"
         # Require parameters
         args = self.convert_args(args)
         # Here where we put our required parameters
@@ -140,9 +140,10 @@ class facile_trigger_helper:
         by_project = args.by_project
 
         #  env to run
-        if not facile_env:
+        if args.env_auto:
             facile_env = args.env_auto
 
+        print(color("Running automation on " + facile_env + " env", fg='yellow'))
         #  Moving args to local variables
         git_lab_host = args.git_lab_host
         project_id = args.project_id
